@@ -1,6 +1,7 @@
 import os
 import sys
 import tqdm
+import torch
 import logging
 import requests
 from transformers import set_seed
@@ -213,9 +214,10 @@ def download_pretrained_model(args, config_only=False):
 
 
 def set_logger(args):
-    # 파이토치 라이트닝이 학습 초반부에 로그를 두 번씩 찍는 버그가 있어
-    # 이를 해결하기 위해 handler를 빈 리스트로 초기화한다
-    lightning_logger.handlers = []
+    if torch.cuda.is_available():
+        # 파이토치 라이트닝이 학습 초반부에 로그를 두 번씩 찍는 버그가 있어
+        # 이를 해결하기 위해 handler를 빈 리스트로 초기화한다
+        lightning_logger.handlers = []
     logger.setLevel(logging.INFO)
     logger.info("Training/evaluation parameters %s", args)
 
